==> cutemaze_1.3.2.orig.tar.gz: cutemaze-1.3.2/translations/cutemaze_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>מצטערים</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>לא ניתן להטעין משחק קודם. משחק חדש יוחל כעת.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 חלפו</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>נלקחו %1 צעדים</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>נותרו %1 מתוך %2 מטרות</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>מושהה</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Super</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>בקרה</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>אפשרות</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>צידה והריגה</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>עדין</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>מחסנית</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>מחסנית 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>מחסנית 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>מחסנית 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>מחסנית 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>אלגוריתם:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>מטרות:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>זמן</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>צעדים</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>אלגוריתם</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>ברכותיי!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>משחק</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>הצג היכן היית</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>הצג מספר צעדים שנלקחו</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>הצג זמן שחלף</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>תזוזה חלקה</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>בקרים</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>תזוזה מעלה:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>תזוזה מטה:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>תזוזה שמאלה:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>תזוזה ימינה:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>מתג דגלון:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>מוטיבים</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>הסרה</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>בחר קובץ מוטיב</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>לא ניתן ליצור תיקיית נתונים.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>לא ניתן להעתיק קובץ מוטיב.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>להסיר קובץ המוטיב הנבחר?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>לא ניתן להסיר את המוטיב הנבחר.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהה</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;רמז</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>ניקוד &amp;גבוה</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>זום &amp;פנימה</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>זום ה&amp;חוצה</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>ה&amp;גדרות</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>ה&amp;עדפות...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>משחק מבוך מעלה-מטה</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>סמלים מתוך פרויקט &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>בשימוש תחת הרשיון &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> cutemaze_1.3.5.orig.tar.gz: cutemaze-1.3.5/translations/cutemaze_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>מצטערים</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>לא ניתן להטעין משחק קודם. משחק חדש יוחל כעת.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 חלפו</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>נלקחו %1 צעדים</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>נותרו %1 מתוך %2 מטרות</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>מושהה</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>בקרה</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>אפשרות</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>צידה והריגה</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>עדין</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>מחסנית</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>מחסנית 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>מחסנית 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>מחסנית 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>מחסנית 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>אלגוריתם:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>מטרות:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>זמן</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>צעדים</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>אלגוריתם</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>ברכות!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation>שיאי ניקוד</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>דרגה</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>ניצחת את הציון הגבוה שלך!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>כל הכבוד!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>יש לך שיא חדש!</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>משחק</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>הצג היכן היית</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>הצג מספר צעדים שנלקחו</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>הצג זמן שחלף</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>תזוזה חלקה</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>בקרים</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>תזוזה מעלה:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>תזוזה מטה:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>תזוזה שמאלה:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>תזוזה ימינה:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>מתג דגלון:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>מוטיבים</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>הסרה</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>בחר קובץ מוטיב</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>לא ניתן ליצור תיקיית נתונים.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>לא ניתן להעתיק קובץ מוטיב.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>להסיר קובץ המוטיב הנבחר?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>לא ניתן להסיר את המוטיב הנבחר.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>הצג רמז:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>פ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;השהה</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;רמז</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>ניקוד &amp;גבוה</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>%יציאה</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>זום &amp;פנימה</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>זום &amp;החוצה</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;העדפות...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>משחק מבוך מעלה-מטה</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>סמלים מתוך פרויקט &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>בשימוש תחת הרשיון &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+י</translation>
    </message>
</context>
</TS>
